#include <qfile.h>
#include <qpainter.h>
#include <qpen.h>
#include <qcolor.h>
#include "gfcommon.h"
#include "gfplotdefs.h"
#include "gfcurve.h"
#include "gfcomments.h"
#include "gfscale.h"

#ifndef GFDRAWH
#define GFDRAWH

#define DEV_NONE 0
#define DEV_PS 1
#define DEV_QT 2

/*

	Drawing Class for GF.  Provides a single interface for drawing
	both postscript to a file and Qt Painting.
	
	Initialize this class then all other draw() methods on GF data
	classes, take a pointer to this class as a parameter:
	
		GfCurve curve.draw(GfDraw *gfdraw);
	
	Question: where should conversion from data to pixel coords take
	place?  Class that does this needs to have access to GfScale class.
	
	
	above would be
	
		GfCurve curve.draw(GfDraw *gfdraw, GfScale *scale);
		
	if conversion is done in curve.draw.  That is current setup, and PS
	routines only work on pixel coord data.  Alternative is to have GfDraw 
	know how to draw a curve, thus we reverse to get
	
		GfDraw draw.curve(GfCurve *curve);
		
	and scale could be passed in once as part of init.
	
	lets try the second approach.
	
*/



class GfDraw
{

public:

    GfDraw();

    int initPS(QFile *,GfPlotDefs *, GfScale *); // init for Postscript output

    int initPaint(QPainter *,int ,int, GfPlotDefs *,GfScale *); // init for Qt window version
    
    int initPaintPrinter(QPainter *,int ,int, GfPlotDefs *,GfScale *); // init for Qt printing

    virtual ~GfDraw();
    
    void curve(GfCurve *,int start=SEG_WHOLE_CURVE,int end=0,int color_change=0);
    
    void axes(); // no params, already have GfScale from init
    
    void comments(GfComments *);
    
    virtual void done(); // PS needs to finish up.
    
    int checkPixelCoords(int,int);// see if clicked position is in data
    
    int x_coord(float y); // converts to screen coords
    int y_coord(float y);
        
    
private:

    GfDraw(GfDraw &); // private copy constructors -- should never be called.
    GfDraw(GfDraw *);


    int device;
    
    bool qt_is_printer; // flag if QT output is going to printer.
    
    int xl,xr,yu,yb;
    
    float xmax,xmin,ymax,ymin;
    
    QFile *qfile; 
    
    QPainter *painter;
    
    GfPlotDefs *pdef; // do this or pull out all to local variable with 
    		// current names to avoid rewriting code? do both.
    		
    GfScale *scale;

    char *fonts_used;
    
    int currfont;
    
    char pout[200];
    
    QPen pen;
    
    int qth;
    
    // internal routines -- device dependant
    
    virtual void plot_out(char *);
    
    virtual void line(int ,int *);
    
    virtual void linetype(int t,float patlen=4.0);
    
    virtual void ps_escape_text(char *text);
    
    virtual void ps_fontused(int f);
    
    virtual void linewidth(int t);
    
    virtual void symbol(int x, int y, int t);
    
    virtual int drawnstrlen(char *text,int rot=0);
    
    virtual void text(int tx,int ty,char *tt,int t,float fsize);
    virtual void setQtFont(int font_index, float size);
    virtual void drawQtText(QPoint *pos,char *text,int font_index,float size);
        
    virtual void setcolor(int t);
    
    virtual void plot_rotate(int *tx,int *ty);
    
    void wind (int *x0,int *y0,int  *x ,int  *y,int  *os);
    void endpoint(int u0,int v0,int u,int v,int *f,int *xn,int *yn);
    int chkpt (int xt,int yt);
    void draw_arrow(GfCurve *c,int pt,int x, int y,int x0,int y0,int fill);
    void draw_symbol(int x,int y,int t1,int d);
    
    void show_ticks();
	
    void titlesQT();
    virtual void titlesPS();
    void axes_box();
    void setup_ticks(float max,float min,float step,int type,int x_len,int y_len);
    void lin_ticks(int d,float t,float t1,float t2,int x_len,int y_len);
    void log_ticks(int d,float t1,float t2,float t3,int x_len,int y_len);
    void put_ticks(int d,int x,int y,int x_len,int y_len);
    
    int sign(float x);
    void convert(char *data,float x);
    
    friend class OverlayGfDraw;
        
};

#endif
