#include "gfcommon.h"
#include <qfile.h>

#ifndef GFSCALEH
#define GFSCALEH

/*

	GfScale class 
	


*/

#define SCALE_LIN 0
#define SCALE_LOG 1

#define TT_NONE 0
#define TT_TICKS 1
#define TT_GRIDS 2


class GfScale
{

public:
	GfScale(); 
	GfScale(const GfScale &); // copy constructor
	GfScale(const GfScale *); // copy constructor
	
	virtual ~GfScale();
	
	
	int setXMax(float);
	int setXMin(float);
	int setYMax(float);
	int setYMin(float);
	
	int setXMaxMin(float,float);
	int setYMaxMin(float,float);
		
	int setXLabel(const char *);
	int setYLabel(const char *);
	
	int setXTicksStep(float);
	int setYTicksStep(float);
	
	int setTicksType(int);
	
	int setXLogScale(int );
	int setYLogScale(int );
	
	int setXZeroLine(int );
	int setYZeroLine(int );
	
	float xMax() const ;
	float xMin() const ;
	float yMax() const ;
	float yMin() const ;
	
	void xLabel(char *) const ;
	void yLabel(char *) const ;
	
	int xLabelLen() const ;
	int yLabelLen() const ;
	
	float xTicksStep() const ;
	float yTicksStep() const ;
	
	int ticksType() const ;
	
	int xLogScale() const ;
	int yLogScale() const ;
	
	int xZeroLine() const ;
	int yZeroLine() const ;
	
	void defaults();
	
	void print(OSTREAM *);
	void format(OSTREAM *);
	int readFormat(QFile *in,char *line);
	
	void operator=(const GfScale &); // assignment operator
	

private:

	float xmax,xmin,ymax,ymin;
	
	int tickstype;
	
	float xticksstep,yticksstep;
	
	char *xlabel,*ylabel;
	
	int xlogscale,ylogscale;
	
	int xzero,yzero;

	void init();
	
};

OSTREAM &operator<<(OSTREAM &os, GfScale *m);
OSTREAM &operator<<(OSTREAM &os, GfScale &m);


#endif // GfScale
